resttools
=========

.. automodule:: abjad.tools.resttools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.resttools.MultimeasureRest.MultimeasureRest.MultimeasureRest
      ~abjad.tools.resttools.Rest.Rest.Rest

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.resttools.make_multimeasure_rests.make_multimeasure_rests
      ~abjad.tools.resttools.make_repeated_rests_from_time_signatures.make_repeated_rests_from_time_signatures
      ~abjad.tools.resttools.make_rests.make_rests
